Tutorials
=========

The following introductory tutorials will help you get started with ``21cmFAST``:

.. toctree::
   :maxdepth: 1

   tutorials/defining_input_params
   tutorials/coeval_cubes
   tutorials/lightcones
   tutorials/global_evolution
   tutorials/caching
   tutorials/cli_usage

We also have some more specific tutorials concerning specific physical models:

.. toctree::
   :maxdepth: 1

   tutorials/mini-halos
   tutorials/relative_velocities
   tutorials/halosampler
   tutorials/redshift_space_distortions
